# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dialogflow_v2.proto import (
    session_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2,
)


class SessionsStub(object):
    """A service used for session interactions.

    For more information, see the [API interactions
    guide](https://cloud.google.com/dialogflow/docs/api-overview).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DetectIntent = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Sessions/DetectIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentResponse.FromString,
        )
        self.StreamingDetectIntent = channel.stream_stream(
            "/google.cloud.dialogflow.v2.Sessions/StreamingDetectIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentResponse.FromString,
        )


class SessionsServicer(object):
    """A service used for session interactions.

    For more information, see the [API interactions
    guide](https://cloud.google.com/dialogflow/docs/api-overview).
    """

    def DetectIntent(self, request, context):
        """Processes a natural language query and returns structured, actionable data
        as a result. This method is not idempotent, because it may cause contexts
        and session entity types to be updated, which in turn might affect
        results of future queries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamingDetectIntent(self, request_iterator, context):
        """Processes a natural language query in audio format in a streaming fashion
        and returns structured, actionable data as a result. This method is only
        available via the gRPC API (not REST).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SessionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DetectIntent": grpc.unary_unary_rpc_method_handler(
            servicer.DetectIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentResponse.SerializeToString,
        ),
        "StreamingDetectIntent": grpc.stream_stream_rpc_method_handler(
            servicer.StreamingDetectIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.dialogflow.v2.Sessions", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Sessions(object):
    """A service used for session interactions.

    For more information, see the [API interactions
    guide](https://cloud.google.com/dialogflow/docs/api-overview).
    """

    @staticmethod
    def DetectIntent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Sessions/DetectIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DetectIntentResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StreamingDetectIntent(
        request_iterator,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            "/google.cloud.dialogflow.v2.Sessions/StreamingDetectIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.StreamingDetectIntentResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dialogflow_v2.proto import (
    entity_type_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class EntityTypesStub(object):
    """Service for managing [EntityTypes][google.cloud.dialogflow.v2.EntityType].
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListEntityTypes = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/ListEntityTypes",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesResponse.FromString,
        )
        self.GetEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/GetEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.GetEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
        )
        self.CreateEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/CreateEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.CreateEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
        )
        self.UpdateEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/UpdateEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.UpdateEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
        )
        self.DeleteEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/DeleteEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.DeleteEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.BatchUpdateEntityTypes = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/BatchUpdateEntityTypes",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntityTypesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchDeleteEntityTypes = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/BatchDeleteEntityTypes",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntityTypesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchCreateEntities = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/BatchCreateEntities",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchCreateEntitiesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchUpdateEntities = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/BatchUpdateEntities",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntitiesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchDeleteEntities = channel.unary_unary(
            "/google.cloud.dialogflow.v2.EntityTypes/BatchDeleteEntities",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntitiesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )


class EntityTypesServicer(object):
    """Service for managing [EntityTypes][google.cloud.dialogflow.v2.EntityType].
    """

    def ListEntityTypes(self, request, context):
        """Returns the list of all entity types in the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityType(self, request, context):
        """Retrieves the specified entity type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateEntityType(self, request, context):
        """Creates an entity type in the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEntityType(self, request, context):
        """Updates the specified entity type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteEntityType(self, request, context):
        """Deletes the specified entity type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchUpdateEntityTypes(self, request, context):
        """Updates/Creates multiple entity types in the specified agent.

        Operation <response: [BatchUpdateEntityTypesResponse][google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchDeleteEntityTypes(self, request, context):
        """Deletes entity types in the specified agent.

        Operation <response: [google.protobuf.Empty][google.protobuf.Empty]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchCreateEntities(self, request, context):
        """Creates multiple new entities in the specified entity type.

        Operation <response: [google.protobuf.Empty][google.protobuf.Empty]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchUpdateEntities(self, request, context):
        """Updates or creates multiple entities in the specified entity type. This
        method does not affect entities in the entity type that aren't explicitly
        specified in the request.


        Operation <response: [google.protobuf.Empty][google.protobuf.Empty]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchDeleteEntities(self, request, context):
        """Deletes entities in the specified entity type.


        Operation <response: [google.protobuf.Empty][google.protobuf.Empty]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EntityTypesServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListEntityTypes": grpc.unary_unary_rpc_method_handler(
            servicer.ListEntityTypes,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesResponse.SerializeToString,
        ),
        "GetEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.GetEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.SerializeToString,
        ),
        "CreateEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.CreateEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.CreateEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.SerializeToString,
        ),
        "UpdateEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.UpdateEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.SerializeToString,
        ),
        "DeleteEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.DeleteEntityTypeRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "BatchUpdateEntityTypes": grpc.unary_unary_rpc_method_handler(
            servicer.BatchUpdateEntityTypes,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntityTypesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchDeleteEntityTypes": grpc.unary_unary_rpc_method_handler(
            servicer.BatchDeleteEntityTypes,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntityTypesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchCreateEntities": grpc.unary_unary_rpc_method_handler(
            servicer.BatchCreateEntities,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchCreateEntitiesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchUpdateEntities": grpc.unary_unary_rpc_method_handler(
            servicer.BatchUpdateEntities,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntitiesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchDeleteEntities": grpc.unary_unary_rpc_method_handler(
            servicer.BatchDeleteEntities,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntitiesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.dialogflow.v2.EntityTypes", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class EntityTypes(object):
    """Service for managing [EntityTypes][google.cloud.dialogflow.v2.EntityType].
    """

    @staticmethod
    def ListEntityTypes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/ListEntityTypes",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.ListEntityTypesResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/GetEntityType",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.GetEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/CreateEntityType",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.CreateEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/UpdateEntityType",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.UpdateEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.EntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/DeleteEntityType",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.DeleteEntityTypeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchUpdateEntityTypes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/BatchUpdateEntityTypes",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntityTypesRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchDeleteEntityTypes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/BatchDeleteEntityTypes",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntityTypesRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchCreateEntities(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/BatchCreateEntities",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchCreateEntitiesRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchUpdateEntities(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/BatchUpdateEntities",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchUpdateEntitiesRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchDeleteEntities(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.EntityTypes/BatchDeleteEntities",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_entity__type__pb2.BatchDeleteEntitiesRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/document.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from dialogflow_v2beta1.proto import (
    gcs_pb2 as google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_gcs__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/document.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\rDocumentProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n4google/cloud/dialogflow_v2beta1/proto/document.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a/google/cloud/dialogflow_v2beta1/proto/gcs.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto"\x8f\x05\n\x08\x44ocument\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tmime_type\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12U\n\x0fknowledge_types\x18\x04 \x03(\x0e\x32\x37.google.cloud.dialogflow.v2beta1.Document.KnowledgeTypeB\x03\xe0\x41\x02\x12\x15\n\x0b\x63ontent_uri\x18\x05 \x01(\tH\x00\x12\x15\n\x07\x63ontent\x18\x06 \x01(\tB\x02\x18\x01H\x00\x12\x15\n\x0braw_content\x18\t \x01(\x0cH\x00\x12\x1f\n\x12\x65nable_auto_reload\x18\x0b \x01(\x08\x42\x03\xe0\x41\x01\x12Y\n\x14latest_reload_status\x18\x0c \x01(\x0b\x32\x36.google.cloud.dialogflow.v2beta1.Document.ReloadStatusB\x03\xe0\x41\x03\x1a\\\n\x0cReloadStatus\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12"\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status"K\n\rKnowledgeType\x12\x1e\n\x1aKNOWLEDGE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x46\x41Q\x10\x01\x12\x11\n\rEXTRACTIVE_QA\x10\x02:p\xea\x41m\n"dialogflow.googleapis.com/Document\x12Gprojects/{project}/knowledgeBases/{knowledge_base}/documents/{document}B\x08\n\x06source"N\n\x12GetDocumentRequest\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"dialogflow.googleapis.com/Document"y\n\x14ListDocumentsRequest\x12:\n\x06parent\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\x12"dialogflow.googleapis.com/Document\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"n\n\x15ListDocumentsResponse\x12<\n\tdocuments\x18\x01 \x03(\x0b\x32).google.cloud.dialogflow.v2beta1.Document\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\x95\x01\n\x15\x43reateDocumentRequest\x12:\n\x06parent\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\x12"dialogflow.googleapis.com/Document\x12@\n\x08\x64ocument\x18\x02 \x01(\x0b\x32).google.cloud.dialogflow.v2beta1.DocumentB\x03\xe0\x41\x02"Q\n\x15\x44\x65leteDocumentRequest\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"dialogflow.googleapis.com/Document"\x8f\x01\n\x15UpdateDocumentRequest\x12@\n\x08\x64ocument\x18\x01 \x01(\x0b\x32).google.cloud.dialogflow.v2beta1.DocumentB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"\xb7\x01\n\x1aKnowledgeOperationMetadata\x12U\n\x05state\x18\x01 \x01(\x0e\x32\x41.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.StateB\x03\xe0\x41\x03"B\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x08\n\x04\x44ONE\x10\x03"\x9d\x01\n\x15ReloadDocumentRequest\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"dialogflow.googleapis.com/Document\x12@\n\ngcs_source\x18\x03 \x01(\x0b\x32*.google.cloud.dialogflow.v2beta1.GcsSourceH\x00\x42\x08\n\x06source"s\n(AutoApproveSmartMessagingEntriesResponse\x12\x15\n\renabled_count\x18\x01 \x01(\x05\x12\x16\n\x0e\x64isabled_count\x18\x02 \x01(\x05\x12\x18\n\x10unreviewed_count\x18\x03 \x01(\x05\x32\xfd\x0e\n\tDocuments\x12\x8a\x02\n\rListDocuments\x12\x35.google.cloud.dialogflow.v2beta1.ListDocumentsRequest\x1a\x36.google.cloud.dialogflow.v2beta1.ListDocumentsResponse"\x89\x01\x82\xd3\xe4\x93\x02z\x12\x37/v2beta1/{parent=projects/*/knowledgeBases/*}/documentsZ?\x12=/v2beta1/{parent=projects/*/agent/knowledgeBases/*}/documents\xda\x41\x06parent\x12\xf7\x01\n\x0bGetDocument\x12\x33.google.cloud.dialogflow.v2beta1.GetDocumentRequest\x1a).google.cloud.dialogflow.v2beta1.Document"\x87\x01\x82\xd3\xe4\x93\x02z\x12\x37/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}Z?\x12=/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}\xda\x41\x04name\x12\xba\x02\n\x0e\x43reateDocument\x12\x36.google.cloud.dialogflow.v2beta1.CreateDocumentRequest\x1a\x1d.google.longrunning.Operation"\xd0\x01\x82\xd3\xe4\x93\x02\x8e\x01"7/v2beta1/{parent=projects/*/knowledgeBases/*}/documents:\x08\x64ocumentZI"=/v2beta1/{parent=projects/*/agent/knowledgeBases/*}/documents:\x08\x64ocument\xda\x41\x0fparent,document\xca\x41&\n\x08\x44ocument\x12\x1aKnowledgeOperationMetadata\x12\xa7\x02\n\x0e\x44\x65leteDocument\x12\x36.google.cloud.dialogflow.v2beta1.DeleteDocumentRequest\x1a\x1d.google.longrunning.Operation"\xbd\x01\x82\xd3\xe4\x93\x02z*7/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}Z?*=/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}\xda\x41\x04name\xca\x41\x33\n\x15google.protobuf.Empty\x12\x1aKnowledgeOperationMetadata\x12\xdc\x02\n\x0eUpdateDocument\x12\x36.google.cloud.dialogflow.v2beta1.UpdateDocumentRequest\x1a\x1d.google.longrunning.Operation"\xf2\x01\x82\xd3\xe4\x93\x02\xa0\x01\x32@/v2beta1/{document.name=projects/*/knowledgeBases/*/documents/*}:\x08\x64ocumentZR2F/v2beta1/{document.name=projects/*/agent/knowledgeBases/*/documents/*}:\x08\x64ocument\xda\x41\x14\x64ocument,update_mask\xda\x41\x08\x64ocument\xca\x41&\n\x08\x44ocument\x12\x1aKnowledgeOperationMetadata\x12\xa8\x02\n\x0eReloadDocument\x12\x36.google.cloud.dialogflow.v2beta1.ReloadDocumentRequest\x1a\x1d.google.longrunning.Operation"\xbe\x01\x82\xd3\xe4\x93\x02\x8e\x01">/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}:reload:\x01*ZI"D/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}:reload:\x01*\xca\x41&\n\x08\x44ocument\x12\x1aKnowledgeOperationMetadata\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xab\x01\n#com.google.cloud.dialogflow.v2beta1B\rDocumentProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_gcs__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)


_DOCUMENT_KNOWLEDGETYPE = _descriptor.EnumDescriptor(
    name="KnowledgeType",
    full_name="google.cloud.dialogflow.v2beta1.Document.KnowledgeType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="KNOWLEDGE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FAQ",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="EXTRACTIVE_QA",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=868,
    serialized_end=943,
)
_sym_db.RegisterEnumDescriptor(_DOCUMENT_KNOWLEDGETYPE)

_KNOWLEDGEOPERATIONMETADATA_STATE = _descriptor.EnumDescriptor(
    name="State",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PENDING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RUNNING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DONE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1883,
    serialized_end=1949,
)
_sym_db.RegisterEnumDescriptor(_KNOWLEDGEOPERATIONMETADATA_STATE)


_DOCUMENT_RELOADSTATUS = _descriptor.Descriptor(
    name="ReloadStatus",
    full_name="google.cloud.dialogflow.v2beta1.Document.ReloadStatus",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time",
            full_name="google.cloud.dialogflow.v2beta1.Document.ReloadStatus.time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="google.cloud.dialogflow.v2beta1.Document.ReloadStatus.status",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=774,
    serialized_end=866,
)

_DOCUMENT = _descriptor.Descriptor(
    name="Document",
    full_name="google.cloud.dialogflow.v2beta1.Document",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Document.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.Document.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mime_type",
            full_name="google.cloud.dialogflow.v2beta1.Document.mime_type",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="knowledge_types",
            full_name="google.cloud.dialogflow.v2beta1.Document.knowledge_types",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content_uri",
            full_name="google.cloud.dialogflow.v2beta1.Document.content_uri",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="google.cloud.dialogflow.v2beta1.Document.content",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="raw_content",
            full_name="google.cloud.dialogflow.v2beta1.Document.raw_content",
            index=6,
            number=9,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enable_auto_reload",
            full_name="google.cloud.dialogflow.v2beta1.Document.enable_auto_reload",
            index=7,
            number=11,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="latest_reload_status",
            full_name="google.cloud.dialogflow.v2beta1.Document.latest_reload_status",
            index=8,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_DOCUMENT_RELOADSTATUS],
    enum_types=[_DOCUMENT_KNOWLEDGETYPE],
    serialized_options=b'\352Am\n"dialogflow.googleapis.com/Document\022Gprojects/{project}/knowledgeBases/{knowledge_base}/documents/{document}',
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.dialogflow.v2beta1.Document.source",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=412,
    serialized_end=1067,
)


_GETDOCUMENTREQUEST = _descriptor.Descriptor(
    name="GetDocumentRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetDocumentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetDocumentRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"dialogflow.googleapis.com/Document',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1069,
    serialized_end=1147,
)


_LISTDOCUMENTSREQUEST = _descriptor.Descriptor(
    name="ListDocumentsRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListDocumentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListDocumentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\022"dialogflow.googleapis.com/Document',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListDocumentsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListDocumentsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1149,
    serialized_end=1270,
)


_LISTDOCUMENTSRESPONSE = _descriptor.Descriptor(
    name="ListDocumentsResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListDocumentsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="documents",
            full_name="google.cloud.dialogflow.v2beta1.ListDocumentsResponse.documents",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListDocumentsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1272,
    serialized_end=1382,
)


_CREATEDOCUMENTREQUEST = _descriptor.Descriptor(
    name="CreateDocumentRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateDocumentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateDocumentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\022"dialogflow.googleapis.com/Document',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="document",
            full_name="google.cloud.dialogflow.v2beta1.CreateDocumentRequest.document",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1385,
    serialized_end=1534,
)


_DELETEDOCUMENTREQUEST = _descriptor.Descriptor(
    name="DeleteDocumentRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteDocumentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteDocumentRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"dialogflow.googleapis.com/Document',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1536,
    serialized_end=1617,
)


_UPDATEDOCUMENTREQUEST = _descriptor.Descriptor(
    name="UpdateDocumentRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateDocumentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="document",
            full_name="google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.document",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1620,
    serialized_end=1763,
)


_KNOWLEDGEOPERATIONMETADATA = _descriptor.Descriptor(
    name="KnowledgeOperationMetadata",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.state",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_KNOWLEDGEOPERATIONMETADATA_STATE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1766,
    serialized_end=1949,
)


_RELOADDOCUMENTREQUEST = _descriptor.Descriptor(
    name="ReloadDocumentRequest",
    full_name="google.cloud.dialogflow.v2beta1.ReloadDocumentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"dialogflow.googleapis.com/Document',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.gcs_source",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.source",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1952,
    serialized_end=2109,
)


_AUTOAPPROVESMARTMESSAGINGENTRIESRESPONSE = _descriptor.Descriptor(
    name="AutoApproveSmartMessagingEntriesResponse",
    full_name="google.cloud.dialogflow.v2beta1.AutoApproveSmartMessagingEntriesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="enabled_count",
            full_name="google.cloud.dialogflow.v2beta1.AutoApproveSmartMessagingEntriesResponse.enabled_count",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="disabled_count",
            full_name="google.cloud.dialogflow.v2beta1.AutoApproveSmartMessagingEntriesResponse.disabled_count",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="unreviewed_count",
            full_name="google.cloud.dialogflow.v2beta1.AutoApproveSmartMessagingEntriesResponse.unreviewed_count",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2111,
    serialized_end=2226,
)

_DOCUMENT_RELOADSTATUS.fields_by_name[
    "time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DOCUMENT_RELOADSTATUS.fields_by_name[
    "status"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DOCUMENT_RELOADSTATUS.containing_type = _DOCUMENT
_DOCUMENT.fields_by_name["knowledge_types"].enum_type = _DOCUMENT_KNOWLEDGETYPE
_DOCUMENT.fields_by_name["latest_reload_status"].message_type = _DOCUMENT_RELOADSTATUS
_DOCUMENT_KNOWLEDGETYPE.containing_type = _DOCUMENT
_DOCUMENT.oneofs_by_name["source"].fields.append(
    _DOCUMENT.fields_by_name["content_uri"]
)
_DOCUMENT.fields_by_name["content_uri"].containing_oneof = _DOCUMENT.oneofs_by_name[
    "source"
]
_DOCUMENT.oneofs_by_name["source"].fields.append(_DOCUMENT.fields_by_name["content"])
_DOCUMENT.fields_by_name["content"].containing_oneof = _DOCUMENT.oneofs_by_name[
    "source"
]
_DOCUMENT.oneofs_by_name["source"].fields.append(
    _DOCUMENT.fields_by_name["raw_content"]
)
_DOCUMENT.fields_by_name["raw_content"].containing_oneof = _DOCUMENT.oneofs_by_name[
    "source"
]
_LISTDOCUMENTSRESPONSE.fields_by_name["documents"].message_type = _DOCUMENT
_CREATEDOCUMENTREQUEST.fields_by_name["document"].message_type = _DOCUMENT
_UPDATEDOCUMENTREQUEST.fields_by_name["document"].message_type = _DOCUMENT
_UPDATEDOCUMENTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KNOWLEDGEOPERATIONMETADATA.fields_by_name[
    "state"
].enum_type = _KNOWLEDGEOPERATIONMETADATA_STATE
_KNOWLEDGEOPERATIONMETADATA_STATE.containing_type = _KNOWLEDGEOPERATIONMETADATA
_RELOADDOCUMENTREQUEST.fields_by_name[
    "gcs_source"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_gcs__pb2._GCSSOURCE
)
_RELOADDOCUMENTREQUEST.oneofs_by_name["source"].fields.append(
    _RELOADDOCUMENTREQUEST.fields_by_name["gcs_source"]
)
_RELOADDOCUMENTREQUEST.fields_by_name[
    "gcs_source"
].containing_oneof = _RELOADDOCUMENTREQUEST.oneofs_by_name["source"]
DESCRIPTOR.message_types_by_name["Document"] = _DOCUMENT
DESCRIPTOR.message_types_by_name["GetDocumentRequest"] = _GETDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name["ListDocumentsRequest"] = _LISTDOCUMENTSREQUEST
DESCRIPTOR.message_types_by_name["ListDocumentsResponse"] = _LISTDOCUMENTSRESPONSE
DESCRIPTOR.message_types_by_name["CreateDocumentRequest"] = _CREATEDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name["DeleteDocumentRequest"] = _DELETEDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name["UpdateDocumentRequest"] = _UPDATEDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name[
    "KnowledgeOperationMetadata"
] = _KNOWLEDGEOPERATIONMETADATA
DESCRIPTOR.message_types_by_name["ReloadDocumentRequest"] = _RELOADDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name[
    "AutoApproveSmartMessagingEntriesResponse"
] = _AUTOAPPROVESMARTMESSAGINGENTRIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Document = _reflection.GeneratedProtocolMessageType(
    "Document",
    (_message.Message,),
    {
        "ReloadStatus": _reflection.GeneratedProtocolMessageType(
            "ReloadStatus",
            (_message.Message,),
            {
                "DESCRIPTOR": _DOCUMENT_RELOADSTATUS,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
                "__doc__": """The status of a reload attempt.
    
    Attributes:
        time:
            Output only. The time of a reload attempt. This reload may
            have been triggered automatically or manually and may not have
            succeeded.
        status:
            Output only. The status of a reload attempt or the initial
            load.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Document.ReloadStatus)
            },
        ),
        "DESCRIPTOR": _DOCUMENT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """A knowledge document to be used by a
  [KnowledgeBase][google.cloud.dialogflow.v2beta1.KnowledgeBase].  For
  more information, see the `knowledge base guide
  <https://cloud.google.com/dialogflow/docs/how/knowledge-bases>`__.
  Note: The ``projects.agent.knowledgeBases.documents`` resource is
  deprecated; only use ``projects.knowledgeBases.documents``.
  
  Attributes:
      name:
          Optional. The document resource name. The name must be empty
          when creating a document. Format: ``projects/<Project
          ID>/knowledgeBases/<Knowledge Base ID>/documents/<Document
          ID>``.
      display_name:
          Required. The display name of the document. The name must be
          1024 bytes or less; otherwise, the creation request fails.
      mime_type:
          Required. The MIME type of this document.
      knowledge_types:
          Required. The knowledge type of document content.
      source:
          The source of this document.
      content_uri:
          The URI where the file content is located.  For documents
          stored in Google Cloud Storage, these URIs must have the form
          ``gs://<bucket-name>/<object-name>``.  NOTE: External URLs
          must correspond to public webpages, i.e., they must be indexed
          by Google Search. In particular, URLs for showing documents in
          Google Cloud Storage (i.e. the URL in your browser) are not
          supported. Instead use the ``gs://`` format URI described
          above.
      content:
          The raw content of the document. This field is only permitted
          for EXTRACTIVE_QA and FAQ knowledge types. Note: This field is
          in the process of being deprecated, please use raw_content
          instead.
      raw_content:
          The raw content of the document. This field is only permitted
          for EXTRACTIVE_QA and FAQ knowledge types.
      enable_auto_reload:
          Optional. If true, we try to automatically reload the document
          every day (at a time picked by the system). If false or
          unspecified, we don’t try to automatically reload the
          document.  Currently you can only enable automatic reload for
          documents sourced from a public url, see ``source`` field for
          the source types.  Reload status can be tracked in
          ``latest_reload_status``. If a reload fails, we will keep the
          document unchanged.  If a reload fails with internal errors,
          the system will try to reload the document on the next day. If
          a reload fails with non-retriable errors
          (e.g. PERMISION_DENIED), the system will not try to reload the
          document anymore. You need to manually reload the document
          successfully by calling ``ReloadDocument`` and clear the
          errors.
      latest_reload_status:
          Output only. The time and status of the latest reload. This
          reload may have been triggered automatically or manually and
          may not have succeeded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Document)
    },
)
_sym_db.RegisterMessage(Document)
_sym_db.RegisterMessage(Document.ReloadStatus)

GetDocumentRequest = _reflection.GeneratedProtocolMessageType(
    "GetDocumentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETDOCUMENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.GetDocument][google.cloud.dialogflow.v2
  beta1.Documents.GetDocument].
  
  Attributes:
      name:
          Required. The name of the document to retrieve. Format
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base
          ID>/documents/<Document ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetDocumentRequest)
    },
)
_sym_db.RegisterMessage(GetDocumentRequest)

ListDocumentsRequest = _reflection.GeneratedProtocolMessageType(
    "ListDocumentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDOCUMENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.ListDocuments][google.cloud.dialogflow.
  v2beta1.Documents.ListDocuments].
  
  Attributes:
      parent:
          Required. The knowledge base to list all documents for.
          Format: ``projects/<Project ID>/knowledgeBases/<Knowledge Base
          ID>``.
      page_size:
          The maximum number of items to return in a single page. By
          default 10 and at most 100.
      page_token:
          The next_page_token value returned from a previous list
          request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListDocumentsRequest)
    },
)
_sym_db.RegisterMessage(ListDocumentsRequest)

ListDocumentsResponse = _reflection.GeneratedProtocolMessageType(
    "ListDocumentsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDOCUMENTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Response message for [Documents.ListDocuments][google.cloud.dialogflow
  .v2beta1.Documents.ListDocuments].
  
  Attributes:
      documents:
          The list of documents.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListDocumentsResponse)
    },
)
_sym_db.RegisterMessage(ListDocumentsResponse)

CreateDocumentRequest = _reflection.GeneratedProtocolMessageType(
    "CreateDocumentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEDOCUMENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.CreateDocument][google.cloud.dialogflow
  .v2beta1.Documents.CreateDocument].
  
  Attributes:
      parent:
          Required. The knoweldge base to create a document for. Format:
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base ID>``.
      document:
          Required. The document to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateDocumentRequest)
    },
)
_sym_db.RegisterMessage(CreateDocumentRequest)

DeleteDocumentRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteDocumentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEDOCUMENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.DeleteDocument][google.cloud.dialogflow
  .v2beta1.Documents.DeleteDocument].
  
  Attributes:
      name:
          Required. The name of the document to delete. Format:
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base
          ID>/documents/<Document ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteDocumentRequest)
    },
)
_sym_db.RegisterMessage(DeleteDocumentRequest)

UpdateDocumentRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateDocumentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEDOCUMENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.UpdateDocument][google.cloud.dialogflow
  .v2beta1.Documents.UpdateDocument].
  
  Attributes:
      document:
          Required. The document to update.
      update_mask:
          Optional. Not specified means ``update all``. Currently, only
          ``display_name`` can be updated, an InvalidArgument will be
          returned for attempting to update other fields.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateDocumentRequest)
    },
)
_sym_db.RegisterMessage(UpdateDocumentRequest)

KnowledgeOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "KnowledgeOperationMetadata",
    (_message.Message,),
    {
        "DESCRIPTOR": _KNOWLEDGEOPERATIONMETADATA,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Metadata in google::longrunning::Operation for Knowledge operations.
  
  Attributes:
      state:
          Required. Output only. The current state of this operation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata)
    },
)
_sym_db.RegisterMessage(KnowledgeOperationMetadata)

ReloadDocumentRequest = _reflection.GeneratedProtocolMessageType(
    "ReloadDocumentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RELOADDOCUMENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Request message for [Documents.ReloadDocument][google.cloud.dialogflow
  .v2beta1.Documents.ReloadDocument].
  
  Attributes:
      name:
          Required. The name of the document to reload. Format:
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base
          ID>/documents/<Document ID>``
      source:
          The source for document reloading. Optional. If provided, the
          service will load the contents from the source and update
          document in the knowledge base.
      gcs_source:
          The path for a Cloud Storage source file for reloading
          document content. If not provided, the Document’s existing
          source will be reloaded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ReloadDocumentRequest)
    },
)
_sym_db.RegisterMessage(ReloadDocumentRequest)

AutoApproveSmartMessagingEntriesResponse = _reflection.GeneratedProtocolMessageType(
    "AutoApproveSmartMessagingEntriesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _AUTOAPPROVESMARTMESSAGINGENTRIESRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.document_pb2",
        "__doc__": """Response message for [Documents.AutoApproveSmartMessagingEntries].
  
  Attributes:
      enabled_count:
          Number of smart messaging entries enabled.
      disabled_count:
          Number of smart messaging entries disabled.
      unreviewed_count:
          Number of smart messaging entries unreviewed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.AutoApproveSmartMessagingEntriesResponse)
    },
)
_sym_db.RegisterMessage(AutoApproveSmartMessagingEntriesResponse)


DESCRIPTOR._options = None
_DOCUMENT.fields_by_name["name"]._options = None
_DOCUMENT.fields_by_name["display_name"]._options = None
_DOCUMENT.fields_by_name["mime_type"]._options = None
_DOCUMENT.fields_by_name["knowledge_types"]._options = None
_DOCUMENT.fields_by_name["content"]._options = None
_DOCUMENT.fields_by_name["enable_auto_reload"]._options = None
_DOCUMENT.fields_by_name["latest_reload_status"]._options = None
_DOCUMENT._options = None
_GETDOCUMENTREQUEST.fields_by_name["name"]._options = None
_LISTDOCUMENTSREQUEST.fields_by_name["parent"]._options = None
_CREATEDOCUMENTREQUEST.fields_by_name["parent"]._options = None
_CREATEDOCUMENTREQUEST.fields_by_name["document"]._options = None
_DELETEDOCUMENTREQUEST.fields_by_name["name"]._options = None
_UPDATEDOCUMENTREQUEST.fields_by_name["document"]._options = None
_UPDATEDOCUMENTREQUEST.fields_by_name["update_mask"]._options = None
_KNOWLEDGEOPERATIONMETADATA.fields_by_name["state"]._options = None
_RELOADDOCUMENTREQUEST.fields_by_name["name"]._options = None

_DOCUMENTS = _descriptor.ServiceDescriptor(
    name="Documents",
    full_name="google.cloud.dialogflow.v2beta1.Documents",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=2229,
    serialized_end=4146,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListDocuments",
            full_name="google.cloud.dialogflow.v2beta1.Documents.ListDocuments",
            index=0,
            containing_service=None,
            input_type=_LISTDOCUMENTSREQUEST,
            output_type=_LISTDOCUMENTSRESPONSE,
            serialized_options=b"\202\323\344\223\002z\0227/v2beta1/{parent=projects/*/knowledgeBases/*}/documentsZ?\022=/v2beta1/{parent=projects/*/agent/knowledgeBases/*}/documents\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetDocument",
            full_name="google.cloud.dialogflow.v2beta1.Documents.GetDocument",
            index=1,
            containing_service=None,
            input_type=_GETDOCUMENTREQUEST,
            output_type=_DOCUMENT,
            serialized_options=b"\202\323\344\223\002z\0227/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}Z?\022=/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateDocument",
            full_name="google.cloud.dialogflow.v2beta1.Documents.CreateDocument",
            index=2,
            containing_service=None,
            input_type=_CREATEDOCUMENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\216\001"7/v2beta1/{parent=projects/*/knowledgeBases/*}/documents:\010documentZI"=/v2beta1/{parent=projects/*/agent/knowledgeBases/*}/documents:\010document\332A\017parent,document\312A&\n\010Document\022\032KnowledgeOperationMetadata',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteDocument",
            full_name="google.cloud.dialogflow.v2beta1.Documents.DeleteDocument",
            index=3,
            containing_service=None,
            input_type=_DELETEDOCUMENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b"\202\323\344\223\002z*7/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}Z?*=/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}\332A\004name\312A3\n\025google.protobuf.Empty\022\032KnowledgeOperationMetadata",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateDocument",
            full_name="google.cloud.dialogflow.v2beta1.Documents.UpdateDocument",
            index=4,
            containing_service=None,
            input_type=_UPDATEDOCUMENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b"\202\323\344\223\002\240\0012@/v2beta1/{document.name=projects/*/knowledgeBases/*/documents/*}:\010documentZR2F/v2beta1/{document.name=projects/*/agent/knowledgeBases/*/documents/*}:\010document\332A\024document,update_mask\332A\010document\312A&\n\010Document\022\032KnowledgeOperationMetadata",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ReloadDocument",
            full_name="google.cloud.dialogflow.v2beta1.Documents.ReloadDocument",
            index=5,
            containing_service=None,
            input_type=_RELOADDOCUMENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\216\001">/v2beta1/{name=projects/*/knowledgeBases/*/documents/*}:reload:\001*ZI"D/v2beta1/{name=projects/*/agent/knowledgeBases/*/documents/*}:reload:\001*\312A&\n\010Document\022\032KnowledgeOperationMetadata',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DOCUMENTS)

DESCRIPTOR.services_by_name["Documents"] = _DOCUMENTS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dialogflow_v2beta1.proto import (
    session_entity_type_pb2 as google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class SessionEntityTypesStub(object):
    """Service for managing [SessionEntityTypes][google.cloud.dialogflow.v2beta1.SessionEntityType].
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSessionEntityTypes = channel.unary_unary(
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/ListSessionEntityTypes",
            request_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesResponse.FromString,
        )
        self.GetSessionEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/GetSessionEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.GetSessionEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
        )
        self.CreateSessionEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/CreateSessionEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.CreateSessionEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
        )
        self.UpdateSessionEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/UpdateSessionEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.UpdateSessionEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
        )
        self.DeleteSessionEntityType = channel.unary_unary(
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/DeleteSessionEntityType",
            request_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.DeleteSessionEntityTypeRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class SessionEntityTypesServicer(object):
    """Service for managing [SessionEntityTypes][google.cloud.dialogflow.v2beta1.SessionEntityType].
    """

    def ListSessionEntityTypes(self, request, context):
        """Returns the list of all session entity types in the specified session.

        This method doesn't work with Google Assistant integration.
        Contact Dialogflow support if you need to use session entities
        with Google Assistant integration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSessionEntityType(self, request, context):
        """Retrieves the specified session entity type.

        This method doesn't work with Google Assistant integration.
        Contact Dialogflow support if you need to use session entities
        with Google Assistant integration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateSessionEntityType(self, request, context):
        """Creates a session entity type.

        If the specified session entity type already exists, overrides the
        session entity type.

        This method doesn't work with Google Assistant integration.
        Contact Dialogflow support if you need to use session entities
        with Google Assistant integration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateSessionEntityType(self, request, context):
        """Updates the specified session entity type.

        This method doesn't work with Google Assistant integration.
        Contact Dialogflow support if you need to use session entities
        with Google Assistant integration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteSessionEntityType(self, request, context):
        """Deletes the specified session entity type.

        This method doesn't work with Google Assistant integration.
        Contact Dialogflow support if you need to use session entities
        with Google Assistant integration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SessionEntityTypesServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListSessionEntityTypes": grpc.unary_unary_rpc_method_handler(
            servicer.ListSessionEntityTypes,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesResponse.SerializeToString,
        ),
        "GetSessionEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.GetSessionEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.GetSessionEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.SerializeToString,
        ),
        "CreateSessionEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.CreateSessionEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.CreateSessionEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.SerializeToString,
        ),
        "UpdateSessionEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateSessionEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.UpdateSessionEntityTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.SerializeToString,
        ),
        "DeleteSessionEntityType": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteSessionEntityType,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.DeleteSessionEntityTypeRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.dialogflow.v2beta1.SessionEntityTypes", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class SessionEntityTypes(object):
    """Service for managing [SessionEntityTypes][google.cloud.dialogflow.v2beta1.SessionEntityType].
    """

    @staticmethod
    def ListSessionEntityTypes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/ListSessionEntityTypes",
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.ListSessionEntityTypesResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSessionEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/GetSessionEntityType",
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.GetSessionEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateSessionEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/CreateSessionEntityType",
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.CreateSessionEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateSessionEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/UpdateSessionEntityType",
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.UpdateSessionEntityTypeRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.SessionEntityType.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteSessionEntityType(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2beta1.SessionEntityTypes/DeleteSessionEntityType",
            google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_session__entity__type__pb2.DeleteSessionEntityTypeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\022KnowledgeBaseProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n:google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xb1\x01\n\rKnowledgeBase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\rlanguage_code\x18\x04 \x01(\t:`\xea\x41]\n\'dialogflow.googleapis.com/KnowledgeBase\x12\x32projects/{project}/knowledgeBases/{knowledge_base}"\x8d\x01\n\x19ListKnowledgeBasesRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\x12\'dialogflow.googleapis.com/KnowledgeBase\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01"~\n\x1aListKnowledgeBasesResponse\x12G\n\x0fknowledge_bases\x18\x01 \x03(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBase\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"X\n\x17GetKnowledgeBaseRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'dialogflow.googleapis.com/KnowledgeBase"\xaa\x01\n\x1a\x43reateKnowledgeBaseRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\x12\'dialogflow.googleapis.com/KnowledgeBase\x12K\n\x0eknowledge_base\x18\x02 \x01(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBaseB\x03\xe0\x41\x02"j\n\x1a\x44\x65leteKnowledgeBaseRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'dialogflow.googleapis.com/KnowledgeBase\x12\r\n\x05\x66orce\x18\x02 \x01(\x08"\x9f\x01\n\x1aUpdateKnowledgeBaseRequest\x12K\n\x0eknowledge_base\x18\x01 \x01(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBaseB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01\x32\xe1\x0b\n\x0eKnowledgeBases\x12\x80\x02\n\x12ListKnowledgeBases\x12:.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest\x1a;.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse"q\x82\xd3\xe4\x93\x02\x62\x12+/v2beta1/{parent=projects/*}/knowledgeBasesZ3\x12\x31/v2beta1/{parent=projects/*/agent}/knowledgeBases\xda\x41\x06parent\x12\xed\x01\n\x10GetKnowledgeBase\x12\x38.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"o\x82\xd3\xe4\x93\x02\x62\x12+/v2beta1/{name=projects/*/knowledgeBases/*}Z3\x12\x31/v2beta1/{name=projects/*/agent/knowledgeBases/*}\xda\x41\x04name\x12\xa6\x02\n\x13\x43reateKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"\xa1\x01\x82\xd3\xe4\x93\x02\x82\x01"+/v2beta1/{parent=projects/*}/knowledgeBases:\x0eknowledge_baseZC"1/v2beta1/{parent=projects/*/agent}/knowledgeBases:\x0eknowledge_base\xda\x41\x15parent,knowledge_base\x12\xdb\x01\n\x13\x44\x65leteKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest\x1a\x16.google.protobuf.Empty"o\x82\xd3\xe4\x93\x02\x62*+/v2beta1/{name=projects/*/knowledgeBases/*}Z3*1/v2beta1/{name=projects/*/agent/knowledgeBases/*}\xda\x41\x04name\x12\xda\x02\n\x13UpdateKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"\xd5\x01\x82\xd3\xe4\x93\x02\xa0\x01\x32:/v2beta1/{knowledge_base.name=projects/*/knowledgeBases/*}:\x0eknowledge_baseZR2@/v2beta1/{knowledge_base.name=projects/*/agent/knowledgeBases/*}:\x0eknowledge_base\xda\x41\x1aknowledge_base,update_mask\xda\x41\x0eknowledge_base\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xb0\x01\n#com.google.cloud.dialogflow.v2beta1B\x12KnowledgeBaseProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_KNOWLEDGEBASE = _descriptor.Descriptor(
    name="KnowledgeBase",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.language_code",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A]\n'dialogflow.googleapis.com/KnowledgeBase\0222projects/{project}/knowledgeBases/{knowledge_base}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=274,
    serialized_end=451,
)


_LISTKNOWLEDGEBASESREQUEST = _descriptor.Descriptor(
    name="ListKnowledgeBasesRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\022'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=454,
    serialized_end=595,
)


_LISTKNOWLEDGEBASESRESPONSE = _descriptor.Descriptor(
    name="ListKnowledgeBasesResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="knowledge_bases",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.knowledge_bases",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=597,
    serialized_end=723,
)


_GETKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="GetKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=725,
    serialized_end=813,
)


_CREATEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="CreateKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\022'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="knowledge_base",
            full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.knowledge_base",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=816,
    serialized_end=986,
)


_DELETEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="DeleteKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=988,
    serialized_end=1094,
)


_UPDATEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="UpdateKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="knowledge_base",
            full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.knowledge_base",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1097,
    serialized_end=1256,
)

_LISTKNOWLEDGEBASESRESPONSE.fields_by_name[
    "knowledge_bases"
].message_type = _KNOWLEDGEBASE
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "knowledge_base"
].message_type = _KNOWLEDGEBASE
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "knowledge_base"
].message_type = _KNOWLEDGEBASE
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["KnowledgeBase"] = _KNOWLEDGEBASE
DESCRIPTOR.message_types_by_name[
    "ListKnowledgeBasesRequest"
] = _LISTKNOWLEDGEBASESREQUEST
DESCRIPTOR.message_types_by_name[
    "ListKnowledgeBasesResponse"
] = _LISTKNOWLEDGEBASESRESPONSE
DESCRIPTOR.message_types_by_name["GetKnowledgeBaseRequest"] = _GETKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateKnowledgeBaseRequest"
] = _CREATEKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteKnowledgeBaseRequest"
] = _DELETEKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateKnowledgeBaseRequest"
] = _UPDATEKNOWLEDGEBASEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KnowledgeBase = _reflection.GeneratedProtocolMessageType(
    "KnowledgeBase",
    (_message.Message,),
    {
        "DESCRIPTOR": _KNOWLEDGEBASE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """A knowledge base represents a collection of knowledge documents that
  you provide to Dialogflow. Your knowledge documents contain
  information that may be useful during conversations with end-users.
  Some Dialogflow features use knowledge bases when looking for a
  response to an end-user input.  For more information, see the
  `knowledge base guide
  <https://cloud.google.com/dialogflow/docs/how/knowledge-bases>`__.
  Note: The ``projects.agent.knowledgeBases`` resource is deprecated;
  only use ``projects.knowledgeBases``.
  
  Attributes:
      name:
          The knowledge base resource name. The name must be empty when
          creating a knowledge base. Format: ``projects/<Project
          ID>/knowledgeBases/<Knowledge Base ID>``.
      display_name:
          Required. The display name of the knowledge base. The name
          must be 1024 bytes or less; otherwise, the creation request
          fails.
      language_code:
          Language which represents the KnowledgeBase. When the
          KnowledgeBase is created/updated, this is populated for all
          non en-us languages. If not populated, the default language
          en-us applies.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.KnowledgeBase)
    },
)
_sym_db.RegisterMessage(KnowledgeBase)

ListKnowledgeBasesRequest = _reflection.GeneratedProtocolMessageType(
    "ListKnowledgeBasesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWLEDGEBASESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.ListKnowledgeBases][google.cloud.d
  ialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases].
  
  Attributes:
      parent:
          Required. The project to list of knowledge bases for. Format:
          ``projects/<Project ID>``.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 10 and at most 100.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest)
    },
)
_sym_db.RegisterMessage(ListKnowledgeBasesRequest)

ListKnowledgeBasesResponse = _reflection.GeneratedProtocolMessageType(
    "ListKnowledgeBasesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWLEDGEBASESRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Response message for [KnowledgeBases.ListKnowledgeBases][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases].
  
  Attributes:
      knowledge_bases:
          The list of knowledge bases.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse)
    },
)
_sym_db.RegisterMessage(ListKnowledgeBasesResponse)

GetKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "GetKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.GetKnowledgeBase][google.cloud.dia
  logflow.v2beta1.KnowledgeBases.GetKnowledgeBase].
  
  Attributes:
      name:
          Required. The name of the knowledge base to retrieve. Format
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(GetKnowledgeBaseRequest)

CreateKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "CreateKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.CreateKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.CreateKnowledgeBase].
  
  Attributes:
      parent:
          Required. The project to create a knowledge base for. Format:
          ``projects/<Project ID>``.
      knowledge_base:
          Required. The knowledge base to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(CreateKnowledgeBaseRequest)

DeleteKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.DeleteKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.DeleteKnowledgeBase].
  
  Attributes:
      name:
          Required. The name of the knowledge base to delete. Format:
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base ID>``.
      force:
          Optional. Force deletes the knowledge base. When set to true,
          any documents in the knowledge base are also deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(DeleteKnowledgeBaseRequest)

UpdateKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.UpdateKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.UpdateKnowledgeBase].
  
  Attributes:
      knowledge_base:
          Required. The knowledge base to update.
      update_mask:
          Optional. Not specified means ``update all``. Currently, only
          ``display_name`` can be updated, an InvalidArgument will be
          returned for attempting to update other fields.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(UpdateKnowledgeBaseRequest)


DESCRIPTOR._options = None
_KNOWLEDGEBASE.fields_by_name["display_name"]._options = None
_KNOWLEDGEBASE._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["parent"]._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["page_size"]._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["page_token"]._options = None
_GETKNOWLEDGEBASEREQUEST.fields_by_name["name"]._options = None
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name["parent"]._options = None
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name["knowledge_base"]._options = None
_DELETEKNOWLEDGEBASEREQUEST.fields_by_name["name"]._options = None
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name["knowledge_base"]._options = None
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name["update_mask"]._options = None

_KNOWLEDGEBASES = _descriptor.ServiceDescriptor(
    name="KnowledgeBases",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=1259,
    serialized_end=2764,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListKnowledgeBases",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases",
            index=0,
            containing_service=None,
            input_type=_LISTKNOWLEDGEBASESREQUEST,
            output_type=_LISTKNOWLEDGEBASESRESPONSE,
            serialized_options=b"\202\323\344\223\002b\022+/v2beta1/{parent=projects/*}/knowledgeBasesZ3\0221/v2beta1/{parent=projects/*/agent}/knowledgeBases\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.GetKnowledgeBase",
            index=1,
            containing_service=None,
            input_type=_GETKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b"\202\323\344\223\002b\022+/v2beta1/{name=projects/*/knowledgeBases/*}Z3\0221/v2beta1/{name=projects/*/agent/knowledgeBases/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.CreateKnowledgeBase",
            index=2,
            containing_service=None,
            input_type=_CREATEKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b'\202\323\344\223\002\202\001"+/v2beta1/{parent=projects/*}/knowledgeBases:\016knowledge_baseZC"1/v2beta1/{parent=projects/*/agent}/knowledgeBases:\016knowledge_base\332A\025parent,knowledge_base',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.DeleteKnowledgeBase",
            index=3,
            containing_service=None,
            input_type=_DELETEKNOWLEDGEBASEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002b*+/v2beta1/{name=projects/*/knowledgeBases/*}Z3*1/v2beta1/{name=projects/*/agent/knowledgeBases/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.UpdateKnowledgeBase",
            index=4,
            containing_service=None,
            input_type=_UPDATEKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b"\202\323\344\223\002\240\0012:/v2beta1/{knowledge_base.name=projects/*/knowledgeBases/*}:\016knowledge_baseZR2@/v2beta1/{knowledge_base.name=projects/*/agent/knowledgeBases/*}:\016knowledge_base\332A\032knowledge_base,update_mask\332A\016knowledge_base",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_KNOWLEDGEBASES)

DESCRIPTOR.services_by_name["KnowledgeBases"] = _KNOWLEDGEBASES

# @@protoc_insertion_point(module_scope)
